@@ -8,6 +8,10 @@
 # error "we need an ANSI compiler"
 #endif
 
+#ifndef NO_PATHS_H
+#include <paths.h>
+#endif
+
 #ifndef LOGDIR
 # define LOGDIR "/etc"
 #endif
@@ -15,30 +19,55 @@
 # define SBINDIR "/etc"
 #endif
 
-#define _PATH_BSHELL    "/bin/sh"
-#define _PATH_CSHELL    "/bin/csh"
-#define UT_NAMESIZE     8
-#define _PATH_TTY       "/dev/tty"
-#define TTYTYPES        "/etc/ttytype"
-#define SECURETTY       "/etc/securetty"
-#define _PATH_UTMP      LOGDIR "/utmp"
-#define _PATH_WTMP      LOGDIR "/wtmp"
-
-#define	_PATH_DEFPATH	        "/usr/local/bin:/bin:/usr/bin:."
-#define	_PATH_DEFPATH_ROOT	"/bin:/usr/bin:" SBINDIR
-#define	_PATH_HUSHLOGIN	".hushlogin"
-#define	_PATH_LASTLOG	LOGDIR "/lastlog"
-#define	_PATH_MAILDIR	"/var/spool/mail"
-#define	_PATH_MOTDFILE	"/etc/motd"
-#define	_PATH_NOLOGIN	"/etc/nologin"
-
-#define _PATH_LOGIN	"/bin/login"
-#define _PATH_INITTAB	"/etc/inittab"
-#define _PATH_RC	"/etc/rc"
-#define _PATH_REBOOT	"/usr/bin/reboot"
 #define _PATH_SINGLE	"/etc/singleboot"
-#define _PATH_SECURE	"/etc/securesingle"
-
 #define _PATH_MTAB	"/etc/mtab"
 #define _PATH_UMOUNT	SBINDIR "/umount"
 #define UMOUNT_ARGS	"umount", "-a"
+
+#if 0
+/* These are not used in sources */
+#define UT_NAMESIZE     8
+#define TTYTYPES        "/etc/ttytype"
+#define SECURETTY       "/etc/securetty"
+#define	_PATH_HUSHLOGIN	".hushlogin"
+#define	_PATH_MOTDFILE	"/etc/motd"
+#define _PATH_INITTAB	"/etc/inittab"
+#define _PATH_RC	"/etc/rc"
+#define _PATH_REBOOT	"/usr/bin/reboot"
+#define _PATH_SECURE	"/etc/securesingle"
+#endif  /* 0 */
+
+/* These should come from /usr/include/paths.h */
+#ifndef _PATH_BSHELL
+#define _PATH_BSHELL    "/bin/sh"
+#endif
+#ifndef _PATH_CSHELL
+#define _PATH_CSHELL    "/bin/csh"
+#endif
+#ifndef _PATH_TTY
+#define _PATH_TTY       "/dev/tty"
+#endif
+#ifndef _PATH_UTMP
+#define _PATH_UTMP      LOGDIR "/utmp"
+#endif
+#ifndef _PATH_WTMP
+#define _PATH_WTMP      LOGDIR "/wtmp"
+#endif
+#ifndef _PATH_DEFPATH
+#define	_PATH_DEFPATH	        "/usr/local/bin:/bin:/usr/bin:."
+#endif
+#ifndef _PATH_DEFPATH_ROOT
+#define	_PATH_DEFPATH_ROOT	"/bin:/usr/bin:" SBINDIR
+#endif
+#ifndef _PATH_LASTLOG
+#define	_PATH_LASTLOG	LOGDIR "/lastlog"
+#endif
+#ifndef _PATH_MAILDIR
+#define	_PATH_MAILDIR	"/var/spool/mail"
+#endif
+#ifndef _PATH_NOLOGIN
+#define	_PATH_NOLOGIN	"/etc/nologin"
+#endif
+#ifndef _PATH_LOGIN
+#define _PATH_LOGIN	"/bin/login"
+#endif
